@@ -29,20 +29,38 @@
 /*******************************************************************************/
 #include "weather-home_download.h"
 /*******************************************************************************/
+#ifdef USE_CONIC
+#include <conic/conic.h>
+#define USER_DATA_MAGIC 0xaadcaadc
+static ConIcConnection *connection = NULL;
+#endif
+/*******************************************************************************/
+static GString *url = NULL;
+static GString *full_filename_new_xml = NULL;
+static GSList *tmplist = NULL;
+static struct HtmlFile html_file;
+static gboolean second_attempt = FALSE;
+static CURL *curl_handle = NULL;
+static CURL *curl_multi = NULL;
+static GtkWidget *update_window = NULL;
+/*******************************************************************************/
 /* Create standard Hildon animation small window */
-void create_window_update(){
+static void create_window_update(void){
     update_window = hildon_banner_show_animation(app->main_window,
 						    NULL,
 						    _("Update weather"));
 }
 /*******************************************************************************/
+#ifdef USE_DBUS
 static DBusHandlerResult
 get_connection_status_signal_cb(DBusConnection *connection,
         DBusMessage *message, void *user_data){
 
     gchar *iap_name = NULL, *iap_nw_type = NULL, *iap_state = NULL;
+    
+#ifndef RELEASE
     fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
-
+#endif
     /* check signal */
     if(!dbus_message_is_signal(message,
                 ICD_DBUS_INTERFACE,
@@ -58,24 +76,91 @@ get_connection_status_signal_cb(DBusConnection *connection,
         return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
     }
 
-    fprintf(stderr,"  > iap_state = %s\n", iap_state);
+/*    fprintf(stderr,"OMWeather  - iap_state = %s\n", iap_state);*/
     if(!strcmp(iap_state, "CONNECTED")){
         if(!app->iap_connected){
             app->iap_connected = TRUE;
+	    app->iap_connecting = FALSE;
+	    app->iap_connecting_timer = 0;
+	    if (app->config->downloading_after_connecting)
+		add_current_time_event();
         }
     }
+    else if (!strcmp(iap_state, "CONNECTING")){
+	    app->iap_connected = FALSE;
+	    app->iap_connecting = TRUE;
+	    app->iap_connecting_timer = 0;
+	 }
     else if(app->iap_connected){
-        app->iap_connected = FALSE; /* !!!!!!!!! Need Remove download */
-    }
+    	    app->iap_connected = FALSE; /* !!!!!!!!! Need Remove download */
+	    app->iap_connecting = FALSE;
+	    app->iap_connecting_timer = 0;
+	 }else
+	 {
+	    app->iap_connecting = FALSE;
+	 } 
 
     return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
+#endif
 /*******************************************************************************/
 /* Callback function for request  connection to Internet */
+
+#ifdef USE_CONIC
+#define OSSO_CON_IC_CONNECTING             0x05
+static void connection_cb(ConIcConnection *connection,
+                          ConIcConnectionEvent *event,
+                          gpointer user_data)
+{
+    const gchar *iap_id, *bearer;
+    ConIcConnectionStatus status;
+    ConIcConnectionError error;
+#ifndef RELEASE
+    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
+#endif
+    status = con_ic_connection_event_get_status(event);
+    error = con_ic_connection_event_get_error(event);
+    iap_id = con_ic_event_get_iap_id(CON_IC_EVENT(event));
+    bearer = con_ic_event_get_bearer_type(CON_IC_EVENT(event));
+
+    switch (status) {
+        case CON_IC_STATUS_CONNECTED:
+#ifndef RELEASE
+	    second_attempt = TRUE;
+	    update_weather();
+#endif
+            app->iap_connecting = FALSE;
+    	    app->iap_connected = TRUE;
+	    app->iap_connecting_timer = 0;
+	    break ;
+
+        case CON_IC_STATUS_DISCONNECTED:
+	    app->iap_connected = FALSE;
+	    app->iap_connecting = FALSE;
+	    app->iap_connecting_timer = 0;
+        break;
+        case CON_IC_STATUS_DISCONNECTING:
+	    app->iap_connected = FALSE;
+	    app->iap_connecting = FALSE;
+	    app->iap_connecting_timer = 0;
+            break;
+/*        default:
+    	    app->iap_connected = FALSE;
+	    app->iap_connecting = FALSE;
+            break;
+*/	    
+    }
+}
+#else
+
 void iap_callback(struct iap_event_t *event, void *arg){
+#ifndef RELEASE
+    fprintf(stderr,"%s() %i\n", __PRETTY_FUNCTION__,event->type);
+#endif    
+    app->iap_connecting = FALSE;
     switch(event->type){
 	case OSSO_IAP_CONNECTED:
-#ifdef PC_EMULATOR
+#ifndef RELEASE
 	    second_attempt = TRUE;
 	    update_weather();
 #endif
@@ -89,53 +174,70 @@ void iap_callback(struct iap_event_t *event, void *arg){
 	    hildon_banner_show_information(app->main_window,
 					    NULL,
 					    _("Not connected to Internet"));
+
 	break;
     }
 }
-/*******************************************************************************/
-/* Check connect to Internet and connection if it not */
-gboolean get_connected(void){
-    /* Register a callback function for IAP related events. */
-    if(osso_iap_cb(iap_callback) != OSSO_OK)
-	return FALSE;
-    if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK)
-	return FALSE;
-    return TRUE;
-}
-/*******************************************************************************/
-/* Check connect to Internet */
-gboolean check_connected(void){
-    if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK)
-	return FALSE;
-    return TRUE;
-}
+#endif
 /*******************************************************************************/
 void weather_initialize_dbus(void){
 
-    if (!app->dbus_is_initialize)
-    /* Add D-BUS signal handler for 'status_changed' */
-    {
-        DBusConnection *dbus_conn = dbus_bus_get(DBUS_BUS_SYSTEM, NULL);
-        gchar *filter_string = g_strdup_printf(
-                "interface=%s", ICD_DBUS_INTERFACE);
+    gchar		*filter_string,
+			*tmp;
+    GConfClient		*gconf_client = NULL;
+    DBusConnection	*dbus_conn;
+    
+    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
+    if(!app->dbus_is_initialize){   
+	/* Reseting values */
+        app->iap_connecting = FALSE;
+	app->iap_connected = FALSE;
+	app->iap_connecting_timer = 0;
+	
+	/* Check connection */
+	gconf_client = gconf_client_get_default();
+	if(gconf_client){
+	    tmp = gconf_client_get_string(gconf_client,
+        			    GCONF_KEY_CURRENT_CONNECTIVITY, NULL);
+	    if(tmp){
+    		app->iap_connected = TRUE;
+		g_free(tmp);
+	    }	
+	    else
+		app->iap_connected = FALSE;
+	    gconf_client_clear_cache(gconf_client);
+	    g_object_unref(gconf_client);		
+	} 
+#ifdef USE_CONIC
+	connection = con_ic_connection_new();
+	if(connection != NULL)
+	    g_signal_connect(G_OBJECT(connection), "connection-event",
+                    	     G_CALLBACK(connection_cb),
+                	     GINT_TO_POINTER(USER_DATA_MAGIC));
+#else	
+    	osso_iap_cb(iap_callback);
+#endif
+
+#ifdef USE_DBUS	   
+	/* Add D-BUS signal handler for 'status_changed' */
+        dbus_conn = dbus_bus_get(DBUS_BUS_SYSTEM, NULL);
+        filter_string = g_strdup_printf("interface=%s", ICD_DBUS_INTERFACE);
         /* add match */
         dbus_bus_add_match(dbus_conn, filter_string, NULL);
-
-        g_free (filter_string);
-
-        /* add the callback */
+        g_free(filter_string);
+	/* add the callback */
         dbus_connection_add_filter(dbus_conn,
-                    get_connection_status_signal_cb,
-                    NULL, NULL);
-    
-	osso_iap_cb(iap_callback);
-
+                		    get_connection_status_signal_cb,
+                		    NULL, NULL);	     
+				    
+#endif /* USE_DBUS */
     /* For Debug on i386 */
-    #ifdef PC_EMULATOR
+#ifndef RELEASE
 	app->iap_connected = TRUE; 
-    #endif
+#endif
 	app->dbus_is_initialize = TRUE;
     }
+    
 }
 /*******************************************************************************/
 /* Init easy curl */
@@ -151,17 +253,17 @@ CURL* weather_curl_init(CURL *curl_handle){
     curl_easy_setopt(curl_handle, CURLOPT_CONNECTTIMEOUT, 10); 
     config_update_proxy();
     /* Set Proxy option */
-    if(app->iap_http_proxy_host){ 
-        curl_easy_setopt(curl_handle, CURLOPT_PROXY, app->iap_http_proxy_host); 
-        if(app->iap_http_proxy_port) 
-            curl_easy_setopt(curl_handle, CURLOPT_PROXYPORT, app->iap_http_proxy_port); 
+    if(app->config->iap_http_proxy_host){ 
+        curl_easy_setopt(curl_handle, CURLOPT_PROXY, app->config->iap_http_proxy_host); 
+        if(app->config->iap_http_proxy_port) 
+            curl_easy_setopt(curl_handle, CURLOPT_PROXYPORT, app->config->iap_http_proxy_port); 
     } 
     return curl_handle;    
 }
 /*******************************************************************************/
-int data_read(void *buffer, size_t size, size_t nmemb, void *stream){
+static int data_read(void *buffer, size_t size, size_t nmemb, void *stream){
     int result;
-    struct HtmlFile *out=(struct HtmlFile *)stream;
+    struct HtmlFile *out = (struct HtmlFile *)stream;
 
     if(out && !out->stream){
     /* open file for writing */
@@ -177,7 +279,9 @@ int data_read(void *buffer, size_t size, size_t nmemb, void *stream){
    Returns TRUE if the station is taken from the list
    Else return FLASE. This the end list
 */
-gboolean form_url_and_filename(){
+static gboolean form_url_and_filename(){
+    struct weather_station *ws;
+
     if(tmplist != NULL){
         ws = tmplist->data;
         if(ws->id_station != NULL){
@@ -191,10 +295,10 @@ gboolean form_url_and_filename(){
 	    } 
 	    url = g_string_new(NULL);        
     	    g_string_append_printf(url,"http://xoap.weather.com/weather/local/%s?cc=*&prod=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=%d",
-				    ws->id_station, DAY_DOWNLOAD);
+				    ws->id_station, Max_count_weather_day);
 	    full_filename_new_xml = g_string_new(NULL);        
 	    g_string_append_printf(full_filename_new_xml,"%s/%s.xml.new",
-				    app->weather_dir_name, ws->id_station);
+				    app->config->cache_dir_name, ws->id_station);
 	    tmplist = g_slist_next(tmplist);
 	    /* Forming structure for download data of weather */
 	    html_file.filename = full_filename_new_xml->str;
@@ -210,56 +314,77 @@ gboolean form_url_and_filename(){
 /*******************************************************************************/
 /* Download html/xml file. Call every 100 ms after begin download */
 gboolean download_html(gpointer data){
+    CURLMsg	*msg;
+    CURLMcode	mret;
+    fd_set	rs, ws, es;
+    int		max;
+    gint	num_transfers = 0,
+		num_msgs = 0;
 
-    CURLMsg *msg;
-    CURLMcode mret;
-    fd_set rs;
-    fd_set ws;
-    fd_set es;
-    int max;
+    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
     if(app->popup_window && app->show_update_window){
-	gtk_widget_destroy(app->popup_window);   
-        app->popup_window=NULL;
+        popup_window_destroy();
     }
-    
     /* If not connected and it autoupdate do go away */
-    if (!app->show_update_window && !app->iap_connected){
+    if(!app->show_update_window && !app->iap_connected){
     	app->flag_updating = 0;
 	return FALSE;
     }
-    if (app->iap_connected) {
+    if(app->iap_connected) 
 	second_attempt = TRUE;
-    }	
-    
-    if( app->show_update_window && (!second_attempt) ){
-	/* Check this code */
-/*
-        if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK){
-	    app->flag_updating = 0;
-	    fprintf (stderr,"(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK)");	
-    	    return FALSE;
-	}   
-*/	
-	hildon_banner_show_information(app->main_window, 
-					NULL,
-					_("Not connected to Internet"));
 
-	app->flag_updating = 0; 
-        return FALSE;
+/* Connection wake up */    
+    if( app->show_update_window && (!second_attempt) && (!app->iap_connecting) ){    
+        app->iap_connecting = TRUE;
+#ifdef USE_CONIC
+	if (connection)
+    	    con_ic_connection_connect(connection, CON_IC_CONNECT_FLAG_NONE);
+	else
+	    return FALSE;
+#else
+        if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK){
+    	    fprintf(stderr,"after 1 osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK){\n");		
+
+	}  	
+#endif
+    	app->flag_updating = 0; 
+	second_attempt = TRUE;
+        return TRUE;
     }
-    
+
+    if (app->iap_connecting){
+	/* Check buggy */
+	if (app->iap_connecting_timer > 150){
+	    if(app->show_update_window){
+		if(update_window){
+		    gtk_widget_destroy(update_window);
+		    update_window = NULL;
+		}
+	    	hildon_banner_show_information(app->main_window,
+					    NULL,
+					    _("Not connected to Internet\nConnection time is expired"));
+		app->iap_connecting_timer = 0;
+	    }				    
+	    app->iap_connecting = FALSE;
+	    return FALSE;
+	}else{
+    	    app->iap_connecting_timer++;
+	    return TRUE;
+	}    
+    }
+	
     second_attempt = FALSE;
     /* The second stage */
     /* call curl_multi_perform for read weather data from Inet */
-    if(curl_multi && CURLM_CALL_MULTI_PERFORM
-            == curl_multi_perform(curl_multi, &num_transfers))
+    if(curl_multi && CURLM_CALL_MULTI_PERFORM ==
+            curl_multi_perform(curl_multi, &num_transfers))
         return TRUE; /* return to UI */
     /* The first stage */
     if(!curl_handle){
 	if(app->show_update_window)
     	    create_window_update(); /* Window with update information */
         /* Initialize list */
-        tmplist = stations_view_list;
+        tmplist = app->stations_view_list;
 	if(!form_url_and_filename()){
 	    if(url){
 		g_string_free(url, TRUE);    
@@ -283,14 +408,12 @@ gboolean download_html(gpointer data){
 	FD_ZERO(&ws);
 	FD_ZERO(&es);
 	mret = curl_multi_fdset(curl_multi,&rs,&ws,&es,&max);
-	if (mret != CURLM_OK) {
+	if(mret != CURLM_OK){
 	    fprintf (stderr,"Error CURL\n");
 	}
-		
 	/* set options for the curl easy handle */
         curl_easy_setopt(curl_handle, CURLOPT_WRITEDATA, &html_file);		
         curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, data_read);	
-	
         /* for debug */
         /*    curl_easy_setopt(curl_handle, CURLOPT_URL, "http://127.0.0.1"); */
         /* add the easy handle to a multi session */
@@ -350,7 +473,7 @@ gboolean download_html(gpointer data){
 		    msg->easy_handle = NULL;
 		}
 		*/
-		if (curl_handle){
+		if(curl_handle){
 		    curl_easy_cleanup(curl_handle); 
 		    curl_handle = NULL;
 		}
@@ -376,7 +499,7 @@ gboolean download_html(gpointer data){
 }
 /*******************************************************************************/
 void clean_download(void){
-    if (curl_multi)
+    if(curl_multi)
 	curl_multi_cleanup(curl_multi);
     curl_multi = NULL;
     curl_handle = NULL;
